# 更新日誌

## [未發布]

### 新增
- 

### 修改
- 

### 修復
- 


## [0.1.2] - 2025-03-16

### 新增
- 

### 修改
- 將最低 Python 版本要求從 3.8 提高到 3.10
- 更新 GitHub Actions 工作流程，僅測試 Python 3.10 及更高版本
- 更新 mcp 依賴版本至 1.4.1（最新版本）

### 修復
- 


所有對 playwright-mcp-fetch 的重要更改都將記錄在此文件中。

## [0.1.1] - 2025-03-16

### 新增
- 

### 修改
- 

### 修復
- 

## [0.1.0] - 2024-03-16

### 新增
- 初始版本
- 支援 fetch_html、fetch_markdown、fetch_txt 和 fetch_json 工具
- 支援 stdio 和 SSE 傳輸模式
- Docker 支援
- GitHub Actions CI/CD 自動化 